Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CopyFileContents ¶
CopyFileContents copies the contents of the file named src to the file named by dst. The file will be created if it does not already exist. If the destination file exists, all it's contents will be replaced by the contents of the source file. Credits to 'markc' at stackoverflow (http://stackoverflow.com/questions/21060945/simple-way-to-copy-a-file-in-golang)
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.